@@ -123,7 +123,7 @@ class LandingZone:
         try:
             for page in iterator:
                 for account in page['Accounts']:
-                    account = AwsAccount(account.get('Id'), account.get('Name'), self)
+                    account = AwsAccount(account.get('Id'), account.get('Name'), self, self.account_thresholds)
                     aws_accounts.append(account)
             return aws_accounts
         except self.organizations.exceptions.AccessDeniedException as msg:
@@ -161,6 +161,7 @@ class AwsAccount:  # pylint: disable=too-many-instance-attributes
     id: str  # pylint: disable=invalid-name
     name: str
     landing_zone: LandingZone
+    account_thresholds: list
     energy_label: str = ""
     number_of_critical_high_findings: int = 0
     number_of_medium_findings: int = 0
@@ -170,11 +171,11 @@ class AwsAccount:  # pylint: disable=too-many-instance-attributes
     def __post_init__(self):
         self._logger = logging.getLogger(f'{LOGGER_BASENAME}.{self.__class__.__name__}')
 
-    def calculate_energy_label(self, findings_frame):
+    def calculate_energy_label(self, findings_measurements_frame):
         """Calculates the energy label for the account.
 
         Args:
-            findings_frame: Dataframe with the findings from security hub.
+            findings_measurements_frame: Dataframe with the measurements on findings from security hub.
 
         Returns:
             The energy label of the account based on the provided configuration.
@@ -182,7 +183,7 @@ class AwsAccount:  # pylint: disable=too-many-instance-attributes
         """
         if not self.energy_label:
             self.energy_label = "F"
-            df = findings_frame  # pylint: disable=invalid-name
+            df = findings_measurements_frame  # pylint: disable=invalid-name
             try:
                 open_findings = df[(df['Account ID'] == self.id) & (df['Workflow State'] != 'RESOLVED')]
                 number_of_critical_findings = open_findings[open_findings['Severity'] == 'CRITICAL'].shape[0]
@@ -204,7 +205,7 @@ class AwsAccount:  # pylint: disable=too-many-instance-attributes
                                    f'number of low findings {self.number_of_low_findings}, '
                                    f'and findings have been open for over '
                                    f'{self.max_days_open} days')
-                for threshold in self.landing_zone.account_thresholds:
+                for threshold in self.account_thresholds:
                     if self.number_of_critical_high_findings <= threshold['critical_high'] \
                             and self.number_of_medium_findings <= threshold['medium'] \
                             and self.number_of_low_findings <= threshold['low'] \
@@ -322,6 +323,19 @@ class Finding:  # pylint: disable=too-many-public-methods
         """Record status."""
         return self._data.get('RecordState')
 
+    @property
+    def compliance_framework(self):
+        """Compliance framework."""
+        return 'aws-foundational-security-best-practices' if self.is_aws_foundational_security_best_practices \
+            else 'cis-aws' if self.is_cis \
+            else 'pci-dss' if self.is_pci_dss \
+            else ''
+
+    @property
+    def rule_id(self):
+        """Rule id."""
+        return self._data.get('ProductFields', {}).get('RuleId')
+
     @property
     def compliance_status(self):
         """Compliance status."""
@@ -379,24 +393,13 @@ class Finding:  # pylint: disable=too-many-public-methods
         return self._data
 
     @property
-    def data(self):
-        """Data."""
+    def measurement_data(self):
+        """Measurement data for computing the energy label."""
         return {
-            'Finding Type': self.types,
             'Finding ID': self.id,
             'Account ID': self.aws_account_id,
-            'Finding First Observed At': self.first_observed_at,
-            'Finding Last Observed At': self.last_observed_at,
-            'Finding Created At': self.created_at,
-            'Finding Updated At': self.updated_at,
             'Severity': self.severity,
-            'Title': self.title,
-            'Resource Types': self.resource_types,
-            'Resource IDs': self.resource_ids,
-            'Region': self.region,
-            'Compliance Status': self.compliance_status,
             'Workflow State': self.workflow_status,
-            'Compliance Control': self.compliance_control,
             'Days Open': self.days_open
         }
 
@@ -522,15 +525,15 @@ class _SecurityHub:  # pylint: disable=too-many-instance-attributes
             findings.extend([finding for finding in self._findings if getattr(finding, attribute)])
         return findings
 
-    def get_findings_data_for_frameworks(self, frameworks):
-        """Gets findings data based on provided frameworks.
+    def get_findings_measurement_data_for_frameworks(self, frameworks):
+        """Gets measurement data from findings based on provided frameworks.
 
         Args:
-            frameworks: A list of valid frameworks for filter findings data on.
+            frameworks: A list of valid frameworks for filter measurement finding data on.
 
         Returns:
-            List of findings data matching the provided frameworks.
+            List of measurement data of findings matching the provided frameworks.
 
         """
         findings = self.get_findings_for_frameworks(frameworks)
-        return [finding.data for finding in findings]
+        return [finding.measurement_data for finding in findings]
